cumulusci.robotframework package
================================

.. automodule:: cumulusci.robotframework
   :members:
   :undoc-members:
   :show-inheritance:

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   cumulusci.robotframework.pageobjects

Submodules
----------

cumulusci.robotframework.CumulusCI module
-----------------------------------------

.. automodule:: cumulusci.robotframework.CumulusCI
   :members:
   :undoc-members:
   :show-inheritance:

cumulusci.robotframework.Salesforce module
------------------------------------------

.. automodule:: cumulusci.robotframework.Salesforce
   :members:
   :undoc-members:
   :show-inheritance:

cumulusci.robotframework.locator\_manager module
------------------------------------------------

.. automodule:: cumulusci.robotframework.locator_manager
   :members:
   :undoc-members:
   :show-inheritance:

cumulusci.robotframework.locators\_49 module
--------------------------------------------

.. automodule:: cumulusci.robotframework.locators_49
   :members:
   :undoc-members:
   :show-inheritance:

cumulusci.robotframework.locators\_50 module
--------------------------------------------

.. automodule:: cumulusci.robotframework.locators_50
   :members:
   :undoc-members:
   :show-inheritance:

cumulusci.robotframework.utils module
-------------------------------------

.. automodule:: cumulusci.robotframework.utils
   :members:
   :undoc-members:
   :show-inheritance:
